{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "metaWrap bin refinement",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "mgnify/metawrap_w_checkm_database",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "metawrap",
                "bin_refinement",
                "--quick"
            ],
            "arguments": [
                {
                    "valueFrom": "out_dir",
                    "prefix": "-o"
                },
                {
                    "valueFrom": "$(runtime.ram)",
                    "prefix": "-m"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "-t"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 50,
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#metawrap_bin_refinement.cwl/completion"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "-A"
                    },
                    "id": "#metawrap_bin_refinement.cwl/concoct_bin_dir"
                },
                {
                    "type": "int",
                    "default": 5,
                    "inputBinding": {
                        "prefix": "-x"
                    },
                    "id": "#metawrap_bin_refinement.cwl/contamination"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#metawrap_bin_refinement.cwl/maxbin_bin_dir"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "-B"
                    },
                    "id": "#metawrap_bin_refinement.cwl/metabat_bin_dir"
                }
            ],
            "doc": "https://arxiv.org/abs/1604.03071\nhttp://cab.spbu.ru/files/release3.12.0/manual.html#meta\n",
            "id": "#metawrap_bin_refinement.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$('out_dir/metawrap*/*.fa')"
                    },
                    "id": "#metawrap_bin_refinement.cwl/bins"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('out_dir/metawrap*.contigs')"
                    },
                    "id": "#metawrap_bin_refinement.cwl/contigs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$('out_dir/metawrap*.stats')"
                    },
                    "id": "#metawrap_bin_refinement.cwl/stats"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "metaWrap binning tool",
            "requirements": [
                {
                    "listing": "$(inputs.reads)",
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/metawrap:1.2--0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "metawrap",
                "binning",
                "--concoct",
                "--metabat2",
                "--maxbin2"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o"
                },
                {
                    "valueFrom": "$(runtime.ram)",
                    "prefix": "-m"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "-t"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#metawrap_binning.cwl/contigs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#metawrap_binning.cwl/min_length"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#metawrap_binning.cwl/reads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--run-checkm"
                    },
                    "id": "#metawrap_binning.cwl/run_check_m"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--single-end"
                    },
                    "id": "#metawrap_binning.cwl/single_end"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "$(\"concoct_bins\")"
                    },
                    "id": "#metawrap_binning.cwl/concoct_bins"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "$(\"maxbin2_bins\")"
                    },
                    "id": "#metawrap_binning.cwl/maxbin2_bins"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputBinding": {
                        "glob": "$(\"metabat2_bins\")"
                    },
                    "id": "#metawrap_binning.cwl/metabat2_bins"
                }
            ],
            "doc": "https://arxiv.org/abs/1604.03071\nhttp://cab.spbu.ru/files/release3.12.0/manual.html#meta\n",
            "id": "#metawrap_binning.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/contigs"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/reads"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/metawrap_binning/concoct_bins",
                    "id": "#main/raw_concoct_bins"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/metawrap_binning/maxbin2_bins",
                    "id": "#main/raw_maxbin2_bins"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "outputSource": "#main/metawrap_binning/metabat2_bins",
                    "id": "#main/raw_metabat2_bins"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bin_refinement/bins",
                    "id": "#main/refined_bins"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/metawrap_binning/concoct_bins",
                            "id": "#main/bin_refinement/concoct_bin_dir"
                        },
                        {
                            "source": "#main/metawrap_binning/maxbin2_bins",
                            "id": "#main/bin_refinement/maxbin_bin_dir"
                        },
                        {
                            "source": "#main/metawrap_binning/metabat2_bins",
                            "id": "#main/bin_refinement/metabat_bin_dir"
                        }
                    ],
                    "out": [
                        "#main/bin_refinement/bins"
                    ],
                    "run": "#metawrap_bin_refinement.cwl",
                    "id": "#main/bin_refinement"
                },
                {
                    "in": [
                        {
                            "source": "#main/contigs",
                            "id": "#main/metawrap_binning/contigs"
                        },
                        {
                            "source": "#main/reads",
                            "id": "#main/metawrap_binning/reads"
                        },
                        {
                            "valueFrom": "$(inputs.reads.length == 1)",
                            "id": "#main/metawrap_binning/single_end"
                        }
                    ],
                    "out": [
                        "#main/metawrap_binning/concoct_bins",
                        "#main/metawrap_binning/metabat2_bins",
                        "#main/metawrap_binning/maxbin2_bins"
                    ],
                    "run": "#metawrap_binning.cwl",
                    "id": "#main/metawrap_binning"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "iana": "https://www.iana.org/assignments/media-types/",
        "s": "http://schema.org/"
    }
}
